{{ $img := "" }}

{{ with $source := ($.Resources.ByType "image").GetMatch "{*feature*,*cover*,*thumbnail*}" }}
  {{ $featured := .Fill (printf "1200x630 %s" (default "Smart" .Params.anchor)) }}
  {{ $img = $featured.Permalink }}
{{ else }}
  {{ with default $.Site.Params.images $.Params.images }}
    {{ $img = index . 0 | absURL }}
  {{ end }}
{{ end }}

{{ return $img }}
