{{ $type := default "note" (.Get "type") }}
{{ $icon := .Get "icon" }}
{{ $title := default ($type | title) (.Get "title") }}


<blockquote class="gdoc-hint {{ $type | lower }}">
  <div class="gdoc-hint__title flex align-center">
    {{- with $icon -}}
      <svg class="gdoc-icon {{ . }}"><use xlink:href="#{{ . }}"></use></svg>
      <span>{{ $title }}</span>
    {{- else -}}
      <i class="fa {{ $type | lower }}" title="{{ $title }}"></i>
    {{- end -}}
  </div>
  <div class="gdoc-hint__text">{{ .Inner | $.Page.RenderString }}</div>
</blockquote>
