{{ define "main" }}
  <article class="gdoc-post">
    <header class="gdoc-post__header">
      <h1 class="gdoc-post__title">{{ partial "utils/title" . }}</h1>
      <div class="flex flex-wrap align-center gdoc-post__meta gdoc-post__meta--head">
        {{ partial "posts/metadata.html" . }}
      </div>
    </header>
    <section class="gdoc-markdown">
      {{ partial "utils/content" . }}
    </section>
  </article>
{{ end }}
