<link rel="icon" type="image/svg+xml" href="{{ "favicon/favicon.svg" | relURL }}" />
<link
  rel="icon"
  type="image/png"
  sizes="32x32"
  href="{{ "favicon/favicon-32x32.png" | relURL }}"
/>
<link
  rel="icon"
  type="image/png"
  sizes="16x16"
  href="{{ "favicon/favicon-16x16.png" | relURL }}"
/>
