{{- with partial "utils/featured" . }}
  <meta name="twitter:card" content="summary_large_image" />
{{- else }}
  <meta name="twitter:card" content="summary" />
{{- end }}
<meta name="twitter:title" {{ partial "utils/title" . | printf "content=%q" | safeHTMLAttr }} />
{{- with partial "utils/featured" . }}
  <meta property="twitter:image" content="{{ . }}" />
{{- end }}
{{- with partial "utils/description" . }}
  <meta name="twitter:description" content="{{ . | plainify | htmlUnescape | chomp }}" />
{{- end }}
{{- with .Site.Social.twitter -}}
  <meta name="twitter:site" content="@{{ . }}" />
{{- end }}
