{{ if default true .Site.Params.geekdocSearch }}
  <div class="gdoc-search flex align-center">
    <svg class="gdoc-icon gdoc_search"><use xlink:href="#gdoc_search"></use></svg>
    <input
      type="text"
      id="gdoc-search-input"
      class="gdoc-search__input"
      placeholder="{{ i18n "form_placeholder_search" }}..."
      aria-label="{{ i18n "form_placeholder_search" }}"
      maxlength="64"
      data-site-base-url="{{ .Site.BaseURL }}"
      data-site-lang="{{ .Site.Language.Lang }}"
    />
    <ul id="gdoc-search-results" class="gdoc-search__list"></ul>
  </div>
{{ end }}
