<meta charset="UTF-8" />
<meta name="referrer" content="no-referrer" />
<meta name="viewport" content="width=device-width, initial-scale=1.0" />
<meta name="color-scheme" content="light dark" />
{{ hugo.Generator }}

{{ $keywords := default .Site.Params.Keywords .Keywords }}

{{- with partial "utils/description" . }}
  <meta name="description" content="{{ trim (. | plainify) "\n" | safeHTML }}" />
{{- end }}
{{- with $keywords }}
  <meta name="keywords" content="{{ delimit . "," }}" />
{{- end }}
